.. Plone Intranet documentation master file, created by
   sphinx-quickstart on Wed Oct 22 15:10:11 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Plone Intranet Documentation
============================

This is the central point for documentation on Plone Intranet. It is maintained by the Plone Intranet Consortium. If you are interested in background information and context of the project, we invite you to have a look at the history.

You can easily - and are very welcome to - contribute to this documentation. Just make a pull request, we'll merge as quick as we can.

Contents:

.. toctree::
   :maxdepth: 2

   installation/index

.. toctree::
   :maxdepth: 2

   about/index

.. toctree::
   :maxdepth: 3

   development/index

.. toctree::
   :maxdepth: 2

   documentation/index

.. toctree::
   :maxdepth: 2

   appendices/index

.. toctree::
   :maxdepth: 2

   license

Changelog
---------

.. toctree::
   :maxdepth: 2

   CHANGES

   CHANGES21

   CHANGES20

   CHANGES10
